@@ -7,10 +7,12 @@ from .background_fill import BackgroundFill
 from .background_fill_freeform_gradient import BackgroundFillFreeformGradient
 from .background_fill_gradient import BackgroundFillGradient
 from .background_fill_solid import BackgroundFillSolid
+from .background_fill_union import BackgroundFillUnion
 from .background_type import BackgroundType
 from .background_type_chat_theme import BackgroundTypeChatTheme
 from .background_type_fill import BackgroundTypeFill
 from .background_type_pattern import BackgroundTypePattern
+from .background_type_union import BackgroundTypeUnion
 from .background_type_wallpaper import BackgroundTypeWallpaper
 from .base import UNSET_PARSE_MODE, TelegramObject
 from .birthdate import Birthdate
@@ -25,6 +27,7 @@ from .bot_command_scope_chat import BotCommandScopeChat
 from .bot_command_scope_chat_administrators import BotCommandScopeChatAdministrators
 from .bot_command_scope_chat_member import BotCommandScopeChatMember
 from .bot_command_scope_default import BotCommandScopeDefault
+from .bot_command_scope_union import BotCommandScopeUnion
 from .bot_description import BotDescription
 from .bot_name import BotName
 from .bot_short_description import BotShortDescription
@@ -46,8 +49,10 @@ from .chat_boost_source import ChatBoostSource
 from .chat_boost_source_gift_code import ChatBoostSourceGiftCode
 from .chat_boost_source_giveaway import ChatBoostSourceGiveaway
 from .chat_boost_source_premium import ChatBoostSourcePremium
+from .chat_boost_source_union import ChatBoostSourceUnion
 from .chat_boost_updated import ChatBoostUpdated
 from .chat_full_info import ChatFullInfo
+from .chat_id_union import ChatIdUnion
 from .chat_invite_link import ChatInviteLink
 from .chat_join_request import ChatJoinRequest
 from .chat_location import ChatLocation
@@ -58,6 +63,7 @@ from .chat_member_left import ChatMemberLeft
 from .chat_member_member import ChatMemberMember
 from .chat_member_owner import ChatMemberOwner
 from .chat_member_restricted import ChatMemberRestricted
+from .chat_member_union import ChatMemberUnion
 from .chat_member_updated import ChatMemberUpdated
 from .chat_permissions import ChatPermissions
 from .chat_photo import ChatPhoto
@@ -66,6 +72,7 @@ from .chosen_inline_result import ChosenInlineResult
 from .contact import Contact
 from .copy_text_button import CopyTextButton
 from .custom import DateTime
+from .date_time_union import DateTimeUnion
 from .dice import Dice
 from .document import Document
 from .downloadable import Downloadable
@@ -112,12 +119,14 @@ from .inline_query_result_gif import InlineQueryResultGif
 from .inline_query_result_location import InlineQueryResultLocation
 from .inline_query_result_mpeg4_gif import InlineQueryResultMpeg4Gif
 from .inline_query_result_photo import InlineQueryResultPhoto
+from .inline_query_result_union import InlineQueryResultUnion
 from .inline_query_result_venue import InlineQueryResultVenue
 from .inline_query_result_video import InlineQueryResultVideo
 from .inline_query_result_voice import InlineQueryResultVoice
 from .inline_query_results_button import InlineQueryResultsButton
 from .input_contact_message_content import InputContactMessageContent
 from .input_file import BufferedInputFile, FSInputFile, InputFile, URLInputFile
+from .input_file_union import InputFileUnion
 from .input_invoice_message_content import InputInvoiceMessageContent
 from .input_location_message_content import InputLocationMessageContent
 from .input_media import InputMedia
@@ -125,12 +134,16 @@ from .input_media_animation import InputMediaAnimation
 from .input_media_audio import InputMediaAudio
 from .input_media_document import InputMediaDocument
 from .input_media_photo import InputMediaPhoto
+from .input_media_union import InputMediaUnion
 from .input_media_video import InputMediaVideo
 from .input_message_content import InputMessageContent
+from .input_message_content_union import InputMessageContentUnion
 from .input_paid_media import InputPaidMedia
 from .input_paid_media_photo import InputPaidMediaPhoto
+from .input_paid_media_union import InputPaidMediaUnion
 from .input_paid_media_video import InputPaidMediaVideo
 from .input_poll_option import InputPollOption
+from .input_poll_option_union import InputPollOptionUnion
 from .input_sticker import InputSticker
 from .input_text_message_content import InputTextMessageContent
 from .input_venue_message_content import InputVenueMessageContent
@@ -146,9 +159,12 @@ from .location import Location
 from .login_url import LoginUrl
 from .mask_position import MaskPosition
 from .maybe_inaccessible_message import MaybeInaccessibleMessage
+from .maybe_inaccessible_message_union import MaybeInaccessibleMessageUnion
+from .media_union import MediaUnion
 from .menu_button import MenuButton
 from .menu_button_commands import MenuButtonCommands
 from .menu_button_default import MenuButtonDefault
+from .menu_button_union import MenuButtonUnion
 from .menu_button_web_app import MenuButtonWebApp
 from .message import ContentType, Message
 from .message_auto_delete_timer_changed import MessageAutoDeleteTimerChanged
@@ -158,6 +174,7 @@ from .message_origin import MessageOrigin
 from .message_origin_channel import MessageOriginChannel
 from .message_origin_chat import MessageOriginChat
 from .message_origin_hidden_user import MessageOriginHiddenUser
+from .message_origin_union import MessageOriginUnion
 from .message_origin_user import MessageOriginUser
 from .message_reaction_count_updated import MessageReactionCountUpdated
 from .message_reaction_updated import MessageReactionUpdated
@@ -167,6 +184,7 @@ from .paid_media_info import PaidMediaInfo
 from .paid_media_photo import PaidMediaPhoto
 from .paid_media_preview import PaidMediaPreview
 from .paid_media_purchased import PaidMediaPurchased
+from .paid_media_union import PaidMediaUnion
 from .paid_media_video import PaidMediaVideo
 from .passport_data import PassportData
 from .passport_element_error import PassportElementError
@@ -180,6 +198,7 @@ from .passport_element_error_translation_file import PassportElementErrorTransla
 from .passport_element_error_translation_files import (
     PassportElementErrorTranslationFiles,
 )
+from .passport_element_error_union import PassportElementErrorUnion
 from .passport_element_error_unspecified import PassportElementErrorUnspecified
 from .passport_file import PassportFile
 from .photo_size import PhotoSize
@@ -194,15 +213,20 @@ from .reaction_type import ReactionType
 from .reaction_type_custom_emoji import ReactionTypeCustomEmoji
 from .reaction_type_emoji import ReactionTypeEmoji
 from .reaction_type_paid import ReactionTypePaid
+from .reaction_type_union import ReactionTypeUnion
 from .refunded_payment import RefundedPayment
 from .reply_keyboard_markup import ReplyKeyboardMarkup
 from .reply_keyboard_remove import ReplyKeyboardRemove
+from .reply_markup_union import ReplyMarkupUnion
 from .reply_parameters import ReplyParameters
 from .response_parameters import ResponseParameters
+from .result_chat_member_union import ResultChatMemberUnion
+from .result_menu_button_union import ResultMenuButtonUnion
 from .revenue_withdrawal_state import RevenueWithdrawalState
 from .revenue_withdrawal_state_failed import RevenueWithdrawalStateFailed
 from .revenue_withdrawal_state_pending import RevenueWithdrawalStatePending
 from .revenue_withdrawal_state_succeeded import RevenueWithdrawalStateSucceeded
+from .revenue_withdrawal_state_union import RevenueWithdrawalStateUnion
 from .sent_web_app_message import SentWebAppMessage
 from .shared_user import SharedUser
 from .shipping_address import ShippingAddress
@@ -223,6 +247,7 @@ from .transaction_partner_fragment import TransactionPartnerFragment
 from .transaction_partner_other import TransactionPartnerOther
 from .transaction_partner_telegram_ads import TransactionPartnerTelegramAds
 from .transaction_partner_telegram_api import TransactionPartnerTelegramApi
+from .transaction_partner_union import TransactionPartnerUnion
 from .transaction_partner_user import TransactionPartnerUser
 from .update import Update
 from .user import User
@@ -251,10 +276,12 @@ __all__ = (
     "BackgroundFillFreeformGradient",
     "BackgroundFillGradient",
     "BackgroundFillSolid",
+    "BackgroundFillUnion",
     "BackgroundType",
     "BackgroundTypeChatTheme",
     "BackgroundTypeFill",
     "BackgroundTypePattern",
+    "BackgroundTypeUnion",
     "BackgroundTypeWallpaper",
     "Birthdate",
     "BotCommand",
@@ -266,6 +293,7 @@ __all__ = (
     "BotCommandScopeChatAdministrators",
     "BotCommandScopeChatMember",
     "BotCommandScopeDefault",
+    "BotCommandScopeUnion",
     "BotDescription",
     "BotName",
     "BotShortDescription",
@@ -288,8 +316,10 @@ __all__ = (
     "ChatBoostSourceGiftCode",
     "ChatBoostSourceGiveaway",
     "ChatBoostSourcePremium",
+    "ChatBoostSourceUnion",
     "ChatBoostUpdated",
     "ChatFullInfo",
+    "ChatIdUnion",
     "ChatInviteLink",
     "ChatJoinRequest",
     "ChatLocation",
@@ -300,6 +330,7 @@ __all__ = (
     "ChatMemberMember",
     "ChatMemberOwner",
     "ChatMemberRestricted",
+    "ChatMemberUnion",
     "ChatMemberUpdated",
     "ChatPermissions",
     "ChatPhoto",
@@ -309,6 +340,7 @@ __all__ = (
     "ContentType",
     "CopyTextButton",
     "DateTime",
+    "DateTimeUnion",
     "Dice",
     "Document",
     "Downloadable",
@@ -356,12 +388,14 @@ __all__ = (
     "InlineQueryResultLocation",
     "InlineQueryResultMpeg4Gif",
     "InlineQueryResultPhoto",
+    "InlineQueryResultUnion",
     "InlineQueryResultVenue",
     "InlineQueryResultVideo",
     "InlineQueryResultVoice",
     "InlineQueryResultsButton",
     "InputContactMessageContent",
     "InputFile",
+    "InputFileUnion",
     "InputInvoiceMessageContent",
     "InputLocationMessageContent",
     "InputMedia",
@@ -369,12 +403,16 @@ __all__ = (
     "InputMediaAudio",
     "InputMediaDocument",
     "InputMediaPhoto",
+    "InputMediaUnion",
     "InputMediaVideo",
     "InputMessageContent",
+    "InputMessageContentUnion",
     "InputPaidMedia",
     "InputPaidMediaPhoto",
+    "InputPaidMediaUnion",
     "InputPaidMediaVideo",
     "InputPollOption",
+    "InputPollOptionUnion",
     "InputSticker",
     "InputTextMessageContent",
     "InputVenueMessageContent",
@@ -390,9 +428,12 @@ __all__ = (
     "LoginUrl",
     "MaskPosition",
     "MaybeInaccessibleMessage",
+    "MaybeInaccessibleMessageUnion",
+    "MediaUnion",
     "MenuButton",
     "MenuButtonCommands",
     "MenuButtonDefault",
+    "MenuButtonUnion",
     "MenuButtonWebApp",
     "Message",
     "MessageAutoDeleteTimerChanged",
@@ -402,6 +443,7 @@ __all__ = (
     "MessageOriginChannel",
     "MessageOriginChat",
     "MessageOriginHiddenUser",
+    "MessageOriginUnion",
     "MessageOriginUser",
     "MessageReactionCountUpdated",
     "MessageReactionUpdated",
@@ -411,6 +453,7 @@ __all__ = (
     "PaidMediaPhoto",
     "PaidMediaPreview",
     "PaidMediaPurchased",
+    "PaidMediaUnion",
     "PaidMediaVideo",
     "PassportData",
     "PassportElementError",
@@ -422,6 +465,7 @@ __all__ = (
     "PassportElementErrorSelfie",
     "PassportElementErrorTranslationFile",
     "PassportElementErrorTranslationFiles",
+    "PassportElementErrorUnion",
     "PassportElementErrorUnspecified",
     "PassportFile",
     "PhotoSize",
@@ -436,15 +480,20 @@ __all__ = (
     "ReactionTypeCustomEmoji",
     "ReactionTypeEmoji",
     "ReactionTypePaid",
+    "ReactionTypeUnion",
     "RefundedPayment",
     "ReplyKeyboardMarkup",
     "ReplyKeyboardRemove",
+    "ReplyMarkupUnion",
     "ReplyParameters",
     "ResponseParameters",
+    "ResultChatMemberUnion",
+    "ResultMenuButtonUnion",
     "RevenueWithdrawalState",
     "RevenueWithdrawalStateFailed",
     "RevenueWithdrawalStatePending",
     "RevenueWithdrawalStateSucceeded",
+    "RevenueWithdrawalStateUnion",
     "SentWebAppMessage",
     "SharedUser",
     "ShippingAddress",
@@ -466,6 +515,7 @@ __all__ = (
     "TransactionPartnerOther",
     "TransactionPartnerTelegramAds",
     "TransactionPartnerTelegramApi",
+    "TransactionPartnerUnion",
     "TransactionPartnerUser",
     "UNSET_PARSE_MODE",
     "URLInputFile",
